#decorators.py
def singleton(class_):
    instances = {}
    def getinstance(*args, **kwargs):
        if class_ not in instances:
            instances[class_] = class_(*args, **kwargs)
        return instances[class_]
    return getinstance



# This is so that you can import ppack or import average from ppack
# in stead of from ppack.functions import average...........

from .decorators import singleton
from .functions import listChunker, report, weirdCase
